@@ -20,8 +20,9 @@ from tradeogre_api.tradeogre_api import TradeOgreAPI
 BASEDIR = os.path.join(os.path.expanduser('~'), '.totui')
 CONFFILE = os.path.join(BASEDIR, 'config.ini')
 COINSFILE = os.path.join(BASEDIR, 'coins.list')
+LOGOFILE = os.path.join(BASEDIR, 'logo.uni')
 CONFIG = configparser.ConfigParser()
-TOTUIVERSION = "TOTUI v1.7.4"
+TOTUIVERSION = "TOTUI v1.7.5"
 
 def read_configuration(confpath):
     """Read the configuration file at given path."""
@@ -31,15 +32,19 @@ def read_configuration(confpath):
         if not os.path.isfile(confpath):
             defaultconf = pkg_resources.resource_filename(__name__, 'config.ini')
             defaultcoins = pkg_resources.resource_filename(__name__, 'coins.list')
+            defaultlogo = pkg_resources.resource_filename(__name__, 'logo.uni')
             shutil.copyfile(defaultconf, CONFFILE)
             shutil.copyfile(defaultcoins, COINSFILE)
+            shutil.copyfile(defaultlogo, LOGOFILE)
 
     else:
         os.mkdir(BASEDIR)
         defaultconf = pkg_resources.resource_filename(__name__, 'config.ini')
         defaultcoins = pkg_resources.resource_filename(__name__, 'coins.list')
+        defaultlogo = pkg_resources.resource_filename(__name__, 'logo.uni')
         shutil.copyfile(defaultconf, CONFFILE)
         shutil.copyfile(defaultcoins, COINSFILE)
+        shutil.copyfile(defaultlogo, LOGOFILE)
         
     CONFIG.read(confpath)
     return CONFIG
@@ -870,7 +875,7 @@ class MainApp(npyscreen.FormWithMenus):
             
         #self.add_handlers({"^O": self.cancel_order})
 
-        with open('logo.uni', 'r') as logo:
+        with open(LOGOFILE, 'r') as logo:
             data = logo.readlines()
         
         linlen=len(data[2])
