@@ -1,6 +1,7 @@
 #!/bin/env python3
 import random
 import undetected_chromedriver as uc
+import os
 from getpass import getpass
 
 from selenium.webdriver.common.keys import Keys
@@ -12,6 +13,7 @@ from datetime import datetime
 from bs4 import BeautifulSoup
 from time import sleep
 
+
 BASEURL = "https://www.tradeogre.com"
 LOGINURL = "https://tradeogre.com/account/signin"
 ORDERSURL = "https://tradeogre.com/account/orders"
@@ -20,6 +22,9 @@ WITHDRAWURL = "https://tradeogre.com/account/history/withdrawals"
 TRADESURL = "https://tradeogre.com/account/history/trades"
 BALANCEURL = "https://tradeogre.com/account/balances"
 
+BASEDIR = os.path.join(os.path.expanduser('~'), '.totui')
+COINSFILE = os.path.join(BASEDIR, 'coins.list')
+
 class SeleniumTradeOgre():
     driver = None
     OpenOrders = []
@@ -348,7 +353,7 @@ class SeleniumTradeOgre():
         
     def populate_CoinList(self): 
 
-        with open("coins.list", "r") as f:
+        with open(COINSFILE, "r") as f:
             TOcoinFILE = f.readlines()
             
         for coin in TOcoinFILE:
